@@ -12,7 +12,7 @@ use Image::WMF::Rectangle;
 use Image::WMF::Polygon;
 use Image::WMF::Image;
 use vars qw($VERSION @ISA @EXPORT $AUTOLOAD);
-$VERSION = "1.02";
+$VERSION = "1.03";
 
 @ISA = qw(Exporter);
 # Items to export into callers namespace by default. Note: do not export
@@ -354,6 +354,11 @@ sub colorAllocate {
 	return($colour);
 }
 
+sub colorExact {
+    my ($self,$r,$g,$b) = @_;
+	return($self->colorAllocate($r,$g,$b));
+}
+
 sub colorDeallocate {
     my ($self,$c) = @_;
 	$c = undef;
